@@ -2,7 +2,12 @@ import logging
 import os
 import sys
 from datetime import datetime
+from multiprocessing import (
+    Queue,
+    Value,
+)
 from pathlib import Path
+from threading import Thread
 from typing import (
     Any,
     Callable,
@@ -44,7 +49,7 @@ if TYPE_CHECKING:
     )
     from logging import LogRecord  # pylint: disable=unused-import
 
-__all__ = ["LogRender", "Handler", "FileHandler"]
+__all__ = ["LogRender", "Handler", "FileHandler", "MultiProcessingHandler"]
 
 FormatTimeCallable = Callable[[datetime], Text]
 
@@ -55,8 +60,6 @@ if sys.platform == "win32":
     color_system = "windows"
 else:
     color_system = "truecolor"
-# noinspection SpellCheckingInspection
-log_console = Console(color_system=color_system, theme=Theme(DEFAULT_STYLE))
 
 
 class LogRender(DefaultLogRender):
@@ -76,15 +79,15 @@ class LogRender(DefaultLogRender):
         self.time_format = logger_config.time_format
 
     def __call__(
-        self,
-        console: "Console",
-        renderables: Iterable["ConsoleRenderable"],
-        log_time: Optional[datetime] = None,
-        time_format: Optional[Union[str, FormatTimeCallable]] = None,
-        level: TextType = "",
-        path: Optional[str] = None,
-        line_no: Optional[int] = None,
-        link_path: Optional[str] = None,
+            self,
+            console: "Console",
+            renderables: Iterable["ConsoleRenderable"],
+            log_time: Optional[datetime] = None,
+            time_format: Optional[Union[str, FormatTimeCallable]] = None,
+            level: TextType = "",
+            path: Optional[str] = None,
+            line_no: Optional[int] = None,
+            link_path: Optional[str] = None,
     ) -> Table:
         from rich.containers import Renderables
 
@@ -99,7 +102,7 @@ class LogRender(DefaultLogRender):
             output.add_column(style="log.line_no", width=4)
         row: List["RenderableType"] = []
         if self.show_time:
-            log_time = log_time or log_console.get_datetime()
+            log_time = log_time or console.get_datetime()
             time_format = time_format or self.time_format
             if callable(time_format):
                 log_time_display = time_format(log_time)
@@ -134,34 +137,39 @@ class LogRender(DefaultLogRender):
 
 class Handler(DefaultRichHandler):
     def __init__(
-        self,
-        *args,
-        rich_tracebacks: bool = True,
-        locals_max_depth: Optional[int] = None,
-        **kwargs,
+            self,
+            *args,
+            width: int = None,
+            rich_tracebacks: bool = True,
+            locals_max_depth: Optional[int] = None,
+            **kwargs,
     ) -> None:
         from arkologger._logger import logger_config
 
-        super(Handler, self).__init__(*args, rich_tracebacks=rich_tracebacks, **kwargs)
+        super(Handler, self).__init__(*args, rich_tracebacks=rich_tracebacks,
+                                      **kwargs)
         self._log_render = LogRender()
-        self.console = log_console
+        self.console = Console(
+            color_system=color_system, theme=Theme(DEFAULT_STYLE), width=width
+        )
         self.tracebacks_show_locals = True
         self.keywords = self.KEYWORDS + logger_config.keywords
         self.locals_max_depth = locals_max_depth
 
     def render(
-        self,
-        *,
-        record: "LogRecord",
-        traceback: Optional[Traceback],
-        message_renderable: Optional["ConsoleRenderable"],
+            self,
+            *,
+            record: "LogRecord",
+            traceback: Optional[Traceback],
+            message_renderable: Optional["ConsoleRenderable"],
     ) -> "ConsoleRenderable":
         from arkologger._logger import logger_config
 
         if record.pathname != "<input>":
             try:
                 path = str(
-                    Path(record.pathname).relative_to(logger_config.project_root)
+                    Path(record.pathname).relative_to(
+                        logger_config.project_root)
                 )
                 path = path.split(".")[0].replace(os.sep, ".")
             except ValueError:
@@ -205,10 +213,12 @@ class Handler(DefaultRichHandler):
         )
         return log_renderable
 
-    def render_message(self, record: "LogRecord", message: Any) -> "ConsoleRenderable":
+    def render_message(self, record: "LogRecord",
+                       message: Any) -> "ConsoleRenderable":
         use_markup = getattr(record, "markup", self.markup)
         if isinstance(message, str):
-            message_text = Text.from_markup(message) if use_markup else Text(message)
+            message_text = Text.from_markup(message) if use_markup else Text(
+                message)
             highlighter = getattr(record, "highlighter", self.highlighter)
         else:
             from rich.highlighter import JSONHighlighter
@@ -233,9 +243,9 @@ class Handler(DefaultRichHandler):
         message = self.format(record)
         _traceback = None
         if (
-            self.rich_tracebacks
-            and record.exc_info
-            and record.exc_info != (None, None, None)
+                self.rich_tracebacks
+                and record.exc_info
+                and record.exc_info != (None, None, None)
         ):
             exc_type, exc_value, exc_traceback = record.exc_info
             if exc_type is None or exc_value is None:
@@ -248,11 +258,11 @@ class Handler(DefaultRichHandler):
                 extra_lines=self.tracebacks_extra_lines,
                 word_wrap=self.tracebacks_word_wrap,
                 show_locals=getattr(record, "show_locals", None)
-                or self.tracebacks_show_locals,
+                            or self.tracebacks_show_locals,
                 locals_max_length=getattr(record, "locals_max_length", None)
-                or self.locals_max_length,
+                                  or self.locals_max_length,
                 locals_max_string=getattr(record, "locals_max_string", None)
-                or self.locals_max_string,
+                                  or self.locals_max_string,
                 locals_max_depth=(
                     getattr(record, "locals_max_depth")
                     if hasattr(record, "locals_max_depth")
@@ -265,20 +275,23 @@ class Handler(DefaultRichHandler):
                 record.message = record.getMessage()
                 formatter = self.formatter
                 if hasattr(formatter, "usesTime") and formatter.usesTime():
-                    record.asctime = formatter.formatTime(record, formatter.datefmt)
+                    record.asctime = formatter.formatTime(record,
+                                                          formatter.datefmt)
                 message = formatter.formatMessage(record)
             if message == str(exc_value):
                 message = None
 
         if message is not None:
             try:
-                message_renderable = self.render_message(record, json.loads(message))
+                message_renderable = self.render_message(record,
+                                                         json.loads(message))
             except JSONDecodeError:
                 message_renderable = self.render_message(record, message)
         else:
             message_renderable = None
         log_renderable = self.render(
-            record=record, traceback=_traceback, message_renderable=message_renderable
+            record=record, traceback=_traceback,
+            message_renderable=message_renderable
         )
         # noinspection PyBroadException
         try:
@@ -287,9 +300,89 @@ class Handler(DefaultRichHandler):
             self.handleError(record)
 
 
-class FileHandler(Handler):
+class MultiProcessingHandler(Handler):
     def __init__(
-        self, *args, path: Path, max_file_size: Optional[int] = None, **kwargs
+            self,
+            *args,
+            rich_tracebacks: bool = True,
+            locals_max_depth: Optional[int] = None,
+            **kwargs,
+    ) -> None:
+        super(MultiProcessingHandler, self).__init__(
+            *args,
+            rich_tracebacks=rich_tracebacks,
+            locals_max_depth=locals_max_depth,
+            **kwargs,
+        )
+        self.queue = Queue(-1)
+        self._is_closed = Value("i", False)
+        # The thread handles receiving records asynchronously.
+        self._receive_thread = Thread(target=self._receive, name=self.name)
+        self._receive_thread.daemon = True
+        self._receive_thread.start()
+
+    def _receive(self):
+        while True:
+            try:
+                if self._is_closed.value and self.queue.empty():
+                    break
+                if not self.queue.empty():
+                    record = self.queue.get_nowait()
+                    super(MultiProcessingHandler, self).emit(record)
+            except (KeyboardInterrupt, SystemExit):
+                raise
+            except (BrokenPipeError, EOFError):
+                break
+            except Exception:
+                from sys import stderr
+                from traceback import print_exc
+
+                print_exc(file=stderr)
+                raise
+
+        self.queue.close()
+        self.queue.join_thread()
+
+    def _send(self, s):
+        self.queue.put_nowait(s)
+
+    def _format_record(self, record):
+
+        if record.args:
+            record.msg = record.msg % record.args
+            record.args = None
+        if record.exc_info:
+            self.format(record)
+            record.exc_info = None
+
+        return record
+
+    def emit(self, record):
+        # noinspection PyBroadException
+        try:
+            s = self._format_record(record)
+            self._send(s)
+        except (KeyboardInterrupt, SystemExit):
+            raise
+        except Exception:
+            self.handleError(record)
+
+    def close(self):
+        if not self._is_closed.value:
+            self._is_closed.value = True
+            self._receive_thread.join(3.0)
+
+            super(MultiProcessingHandler, self).close()
+
+
+class FileHandler(MultiProcessingHandler):
+    def __init__(
+            self,
+            *args,
+            width: int = None,
+            path: Path,
+            max_file_size: Optional[int] = None,
+            **kwargs,
     ) -> None:
         super().__init__(*args, **kwargs)
         while True:
@@ -306,5 +399,6 @@ class FileHandler(Handler):
                         parent = parent.parent
         path.parent.mkdir(exist_ok=True)
         self.console = Console(
-            width=180, file=FileIO(path, max_file_size), theme=Theme(DEFAULT_STYLE)
+            width=width, file=FileIO(path, max_file_size),
+            theme=Theme(DEFAULT_STYLE)
         )
